@@ -28,6 +28,13 @@ Launcher::Launcher(MainWindow *main)
 		this, SLOT(startXTerm()));
 }
 
+void Launcher::activateButtons(bool activate)
+{
+	m_buttons[PASSWD_BUTTON]->setEnabled(activate);
+	m_buttons[METHER_BUTTON]->setEnabled(activate);
+	m_buttons[XTERM_BUTTON]->setEnabled(activate);
+}
+
 void
 Launcher::startXTerm(void)
 {
